==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridColumnOptionsSectionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsBaseDescriptionMetadata } from "./GridColumnOptionsBaseDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsSectionBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnOptionsSectionBaseDescriptionMetadata, _super);
    function GridColumnOptionsSectionBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsSectionBaseDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsSectionBaseDescriptionMetadata.a == null) {
            GridColumnOptionsSectionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsSectionBaseDescriptionMetadata.c(GridColumnOptionsSectionBaseDescriptionMetadata.a);
        }
        if (a.g(GridColumnOptionsSectionBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(GridColumnOptionsSectionBaseDescriptionMetadata.a);
    };
    GridColumnOptionsSectionBaseDescriptionMetadata.c = function (a) {
        GridColumnOptionsBaseDescriptionMetadata.c(a);
    };
    GridColumnOptionsSectionBaseDescriptionMetadata.d = function (a) {
        GridColumnOptionsSectionBaseDescriptionMetadata.b(a);
        a.t("GridColumnOptionsSectionBase", GridColumnOptionsSectionBaseDescriptionMetadata.a);
    };
    GridColumnOptionsSectionBaseDescriptionMetadata.$t = markType(GridColumnOptionsSectionBaseDescriptionMetadata, 'GridColumnOptionsSectionBaseDescriptionMetadata');
    GridColumnOptionsSectionBaseDescriptionMetadata.a = null;
    return GridColumnOptionsSectionBaseDescriptionMetadata;
}(Base));
export { GridColumnOptionsSectionBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridColumnOptionsSectionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsBaseDescriptionMetadata } from "./GridColumnOptionsBaseDescriptionMetadata";
/**
 * @hidden
 */
var GridColumnOptionsSectionBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnOptionsSectionBaseDescriptionMetadata, _super);
    function GridColumnOptionsSectionBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnOptionsSectionBaseDescriptionMetadata.b = function (a) {
        if (GridColumnOptionsSectionBaseDescriptionMetadata.a == null) {
            GridColumnOptionsSectionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnOptionsSectionBaseDescriptionMetadata.c(GridColumnOptionsSectionBaseDescriptionMetadata.a);
        }
        if (a.j(GridColumnOptionsSectionBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnOptionsSectionBaseDescriptionMetadata.a);
    };
    GridColumnOptionsSectionBaseDescriptionMetadata.c = function (a) {
        GridColumnOptionsBaseDescriptionMetadata.c(a);
    };
    GridColumnOptionsSectionBaseDescriptionMetadata.d = function (a) {
        GridColumnOptionsSectionBaseDescriptionMetadata.b(a);
        a.z("GridColumnOptionsSectionBase", GridColumnOptionsSectionBaseDescriptionMetadata.a);
    };
    GridColumnOptionsSectionBaseDescriptionMetadata.$t = markType(GridColumnOptionsSectionBaseDescriptionMetadata, 'GridColumnOptionsSectionBaseDescriptionMetadata');
    GridColumnOptionsSectionBaseDescriptionMetadata.a = null;
    return GridColumnOptionsSectionBaseDescriptionMetadata;
}(Base));
export { GridColumnOptionsSectionBaseDescriptionMetadata };
